/*
 * Copyright 2020 - MATTR Limited
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *     http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import type { VerificationMethod, JsonObject, Proof, DocumentLoader } from '@credo-ts/core'

/**
 * Options for verifying a signature
 */
export interface VerifySignatureOptions {
  /**
   * Document to verify
   */
  readonly document: JsonObject
  /**
   * Array of statements to verify
   */
  readonly verifyData: Uint8Array[]
  /**
   * Verification method to verify the signature against
   */
  readonly verificationMethod: VerificationMethod
  /**
   * Proof to verify
   */
  readonly proof: Proof
  /**
   * Optional custom document loader
   */
  documentLoader?: DocumentLoader
}
